@@ -5,13 +5,18 @@ from trytond.model import fields
 from trytond.pyson import Eval
 
 
-__all__ = ['Template']
+__all__ = ['Template', 'Product']
 
 
 class Template:
-    __name__ = 'product.template'
     __metaclass__ = PoolMeta
+    __name__ = 'product.template'
     landed_cost = fields.Boolean('Landed Cost', states={
             'readonly': ~Eval('active', True),
             'invisible': Eval('type') != 'service',
             }, depends=['active', 'type'])
+
+
+class Product:
+    __metaclass__ = PoolMeta
+    __name__ = 'product.product'
